==> daily-templates-0.6.1.tgz: package/lib/components/Share.js <==
'use strict';

var React = require('react');
var update = require('immutability-helper');

var Share = function Share(_ref) {
  var data = _ref.data,
      isEditing = _ref.isEditing,
      updateData = _ref.updateData;
  return isEditing ? React.createElement(
    'div',
    { className: 'blurb blurb-share-editing' },
    React.createElement(
      'div',
      { className: 'blurb-share-email-editing' },
      React.createElement('input', {
        className: 'blurb-share-email-editing-href',
        type: 'text',
        value: data.email.href,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              $set: { href: event.target.value }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-email-editing-src',
        type: 'text',
        value: data.email.img.src,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              img: {
                $set: { src: event.target.value }
              }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-email-editing-alt',
        type: 'text',
        value: data.email.img.alt,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              img: {
                $set: { alt: event.target.value }
              }
            }
          }));
        } })
    ),
    React.createElement(
      'div',
      { className: 'blurb-share-sms-editing' },
      React.createElement('input', {
        className: 'blurb-share-sms-editing-href',
        type: 'text',
        value: data.sms.href,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              $set: { href: event.target.value }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-sms-editing-src',
        type: 'text',
        value: data.sms.img.src,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              img: {
                $set: { src: event.target.value }
              }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-sms-editing-alt',
        type: 'text',
        value: data.sms.img.alt,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              img: {
                $set: { alt: event.target.value }
              }
            }
          }));
        } })
    )
  ) : React.createElement(
    'div',
    { className: 'blurb blurb-share' },
    data.email && React.createElement(
      'div',
      { className: 'blurb-share-email' },
      React.createElement(
        'a',
        { className: 'no-underline', href: data.email.href },
        data.email.img && React.createElement('img', { src: data.email.img.src, alt: data.email.img.alt }),
        React.createElement(
          'p',
          null,
          'Send an email'
        )
      )
    ),
    data.sms && React.createElement(
      'div',
      { className: 'blurb-share-sms' },
      React.createElement(
        'a',
        { className: 'no-underline', href: data.sms.href },
        data.sms.img && React.createElement('img', { src: data.sms.img.src, alt: data.sms.img.alt }),
        React.createElement(
          'p',
          null,
          'Send a text'
        )
      )
    )
  );
};

Share.propTypes = {
  data: React.PropTypes.shape({
    email: React.PropTypes.shape({
      href: React.PropTypes.string,
      img: React.PropTypes.shape({
        alt: React.PropTypes.string,
        src: React.PropTypes.string
      })
    }),
    sms: React.PropTypes.shape({
      href: React.PropTypes.string,
      img: React.PropTypes.shape({
        alt: React.PropTypes.string,
        src: React.PropTypes.string
      })
    })
  }),
  isEditing: React.PropTypes.bool,
  updateData: React.PropTypes.func
};

module.exports = Share;

==> daily-templates-0.9.0.tgz: package/lib/components/Share.js <==
'use strict';

var React = require('react');
var PropTypes = require('prop-types');
var update = require('immutability-helper');

var Share = function Share(_ref) {
  var data = _ref.data,
      isEditing = _ref.isEditing,
      updateData = _ref.updateData;
  return isEditing ? React.createElement(
    'div',
    { className: 'blurb blurb-share-editing' },
    React.createElement(
      'div',
      { className: 'blurb-share-email-editing' },
      React.createElement('input', {
        className: 'blurb-share-email-editing-href',
        type: 'text',
        value: data.email.href,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              $set: { href: event.target.value }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-email-editing-src',
        type: 'text',
        value: data.email.img.src,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              img: {
                $set: { src: event.target.value }
              }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-email-editing-alt',
        type: 'text',
        value: data.email.img.alt,
        onChange: function onChange(event) {
          return updateData(update(data, {
            email: {
              img: {
                $set: { alt: event.target.value }
              }
            }
          }));
        } })
    ),
    React.createElement(
      'div',
      { className: 'blurb-share-sms-editing' },
      React.createElement('input', {
        className: 'blurb-share-sms-editing-href',
        type: 'text',
        value: data.sms.href,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              $set: { href: event.target.value }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-sms-editing-src',
        type: 'text',
        value: data.sms.img.src,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              img: {
                $set: { src: event.target.value }
              }
            }
          }));
        } }),
      React.createElement('input', {
        className: 'blurb-share-sms-editing-alt',
        type: 'text',
        value: data.sms.img.alt,
        onChange: function onChange(event) {
          return updateData(update(data, {
            sms: {
              img: {
                $set: { alt: event.target.value }
              }
            }
          }));
        } })
    )
  ) : React.createElement(
    'div',
    { className: 'blurb blurb-share' },
    data.email && React.createElement(
      'div',
      { className: 'blurb-share-email' },
      React.createElement(
        'a',
        { className: 'no-underline', href: data.email.href },
        data.email.img && React.createElement('img', { src: data.email.img.src, alt: data.email.img.alt }),
        React.createElement(
          'p',
          null,
          'Send an email'
        )
      )
    ),
    data.sms && React.createElement(
      'div',
      { className: 'blurb-share-sms' },
      React.createElement(
        'a',
        { className: 'no-underline', href: data.sms.href },
        data.sms.img && React.createElement('img', { src: data.sms.img.src, alt: data.sms.img.alt }),
        React.createElement(
          'p',
          null,
          'Send a text'
        )
      )
    )
  );
};

Share.propTypes = {
  data: PropTypes.shape({
    email: PropTypes.shape({
      href: PropTypes.string,
      img: PropTypes.shape({
        alt: PropTypes.string,
        src: PropTypes.string
      })
    }),
    sms: PropTypes.shape({
      href: PropTypes.string,
      img: PropTypes.shape({
        alt: PropTypes.string,
        src: PropTypes.string
      })
    })
  }),
  isEditing: PropTypes.bool,
  updateData: PropTypes.func
};

module.exports = Share;
